@@ -1,7 +1,9 @@
 #![warn(missing_debug_implementations)]
+#![allow(clippy::too_many_arguments)]
+#![allow(clippy::unusual_byte_groupings)]
 
 //! A [Board](crate::board::Board) abstraction for deterministic two player games.
-//! This code to be generic over the actual game, so it only needs to written once.
+//! This allows for code to be generic over the actual game, so it only needs to written once.
 //!
 //! # Features
 //!
@@ -33,7 +35,7 @@
 //!
 //! ```
 //! # use board_game::games::ataxx::AtaxxBoard;
-//! # use board_game::board::{BoardAvailableMoves, Board};
+//! # use board_game::board::{BoardMoves, Board};
 //! # use internal_iterator::InternalIterator;
 //! # let mut rng = rand::thread_rng();
 //!
@@ -69,11 +71,10 @@ pub mod board;
 pub mod symmetry;
 pub mod wdl;
 
-pub mod games;
 pub mod ai;
+pub mod games;
 pub mod heuristic;
 
 pub mod util;
 
 pub mod uai;
-
