@@ -1,5 +1,8 @@
+//! Various utility functions.
 pub mod board_gen;
 pub mod bot_game;
 pub mod game_stats;
 
 pub mod bits;
+
+pub mod rating;
